@@ -39,6 +39,10 @@ Q_SIGNALS:
     void teardownDone(Solid::ErrorType error, QVariant errorData, const QString &udi) override;
     void setupRequested(const QString &udi) override;
     void teardownRequested(const QString &udi) override;
+    void checkRequested(const QString &udi) override;
+    void checkDone(Solid::ErrorType error, QVariant errorData, const QString &udi) override;
+    void repairRequested(const QString &udi) override;
+    void repairDone(Solid::ErrorType error, QVariant errorData, const QString &udi) override;
 
 private Q_SLOTS:
     void onPropertyChanged(const QMap<QString, int> &changes);
